@@ -1,6 +1,6 @@
-use crate::types::{BoxedBytes, MessageHashType};
+use crate::types::{heap::BoxedBytes, MessageHashType};
 
-use super::{Handle, ManagedTypeApi, ManagedTypeApiImpl};
+use super::{ManagedTypeApi, ManagedTypeApiImpl};
 
 pub const SHA256_RESULT_LEN: usize = 32;
 pub const KECCAK256_RESULT_LEN: usize = 32;
@@ -17,11 +17,13 @@ pub trait CryptoApi: ManagedTypeApi {
 pub trait CryptoApiImpl: ManagedTypeApiImpl {
     fn sha256_legacy(&self, data: &[u8]) -> [u8; SHA256_RESULT_LEN];
 
-    fn sha256(&self, data_handle: Handle) -> Handle;
+    #[cfg(feature = "ei-1-1")]
+    fn sha256(&self, data_handle: super::Handle) -> super::Handle;
 
     fn keccak256_legacy(&self, data: &[u8]) -> [u8; KECCAK256_RESULT_LEN];
 
-    fn keccak256(&self, data_handle: Handle) -> Handle;
+    #[cfg(feature = "ei-1-1")]
+    fn keccak256(&self, data_handle: super::Handle) -> super::Handle;
 
     fn ripemd160(&self, data: &[u8]) -> [u8; RIPEMD_RESULT_LEN];
 
