@@ -1,6 +1,6 @@
 use crate::{
     api::{Handle, InvalidSliceError, ManagedBufferApi},
-    types::BoxedBytes,
+    types::heap::BoxedBytes,
 };
 
 impl ManagedBufferApi for super::UncallableApi {
@@ -47,6 +47,7 @@ impl ManagedBufferApi for super::UncallableApi {
         unreachable!()
     }
 
+    #[cfg(feature = "ei-1-1")]
     fn mb_set_slice(
         &self,
         _dest_handle: Handle,
