@@ -7,11 +7,10 @@ use crate::{
     },
     storage::{self},
     types::{
-        Address, BigUint, EsdtLocalRoleFlags, EsdtTokenData, ManagedAddress, ManagedByteArray,
-        ManagedType, TokenIdentifier, H256,
+        BigUint, EsdtLocalRoleFlags, EsdtTokenData, ManagedAddress, ManagedByteArray, ManagedType,
+        TokenIdentifier,
     },
 };
-use alloc::boxed::Box;
 
 /// Interface to be used by the actual smart contract code.
 ///
@@ -37,8 +36,9 @@ where
         }
     }
 
+    #[cfg(feature = "alloc")]
     #[inline]
-    pub fn get_caller_legacy(&self) -> Address {
+    pub fn get_caller_legacy(&self) -> crate::types::Address {
         A::blockchain_api_impl().get_caller_legacy()
     }
 
@@ -47,8 +47,9 @@ where
         ManagedAddress::from_raw_handle(A::blockchain_api_impl().get_caller_handle())
     }
 
+    #[cfg(feature = "alloc")]
     #[inline]
-    pub fn get_sc_address_legacy(&self) -> Address {
+    pub fn get_sc_address_legacy(&self) -> crate::types::Address {
         A::blockchain_api_impl().get_sc_address_legacy()
     }
 
@@ -57,8 +58,9 @@ where
         ManagedAddress::from_raw_handle(A::blockchain_api_impl().get_sc_address_handle())
     }
 
+    #[cfg(feature = "alloc")]
     #[inline]
-    pub fn get_owner_address_legacy(&self) -> Address {
+    pub fn get_owner_address_legacy(&self) -> crate::types::Address {
         A::blockchain_api_impl().get_owner_address_legacy()
     }
 
@@ -73,8 +75,9 @@ where
         }
     }
 
+    #[cfg(feature = "alloc")]
     #[inline]
-    pub fn get_shard_of_address_legacy(&self, address: &Address) -> u32 {
+    pub fn get_shard_of_address_legacy(&self, address: &crate::types::Address) -> u32 {
         A::blockchain_api_impl().get_shard_of_address_legacy(address)
     }
 
@@ -83,8 +86,9 @@ where
         A::blockchain_api_impl().get_shard_of_address(address.get_raw_handle())
     }
 
+    #[cfg(feature = "alloc")]
     #[inline]
-    pub fn is_smart_contract_legacy(&self, address: &Address) -> bool {
+    pub fn is_smart_contract_legacy(&self, address: &crate::types::Address) -> bool {
         A::blockchain_api_impl().is_smart_contract_legacy(address)
     }
 
@@ -93,8 +97,9 @@ where
         A::blockchain_api_impl().is_smart_contract(address.get_raw_handle())
     }
 
+    #[cfg(feature = "alloc")]
     #[inline]
-    pub fn get_balance_legacy(&self, address: &Address) -> BigUint<A> {
+    pub fn get_balance_legacy(&self, address: &crate::types::Address) -> BigUint<A> {
         BigUint::from_raw_handle(A::blockchain_api_impl().get_balance_legacy(address))
     }
 
@@ -114,8 +119,9 @@ where
         }
     }
 
+    #[cfg(feature = "alloc")]
     #[inline]
-    pub fn get_state_root_hash_legacy(&self) -> H256 {
+    pub fn get_state_root_hash_legacy(&self) -> crate::types::H256 {
         A::blockchain_api_impl().get_state_root_hash_legacy()
     }
 
@@ -124,8 +130,9 @@ where
         A::blockchain_api_impl().get_state_root_hash()
     }
 
+    #[cfg(feature = "alloc")]
     #[inline]
-    pub fn get_tx_hash_legacy(&self) -> H256 {
+    pub fn get_tx_hash_legacy(&self) -> crate::types::H256 {
         A::blockchain_api_impl().get_tx_hash_legacy()
     }
 
@@ -159,8 +166,9 @@ where
         A::blockchain_api_impl().get_block_epoch()
     }
 
+    #[cfg(feature = "alloc")]
     #[inline]
-    pub fn get_block_random_seed_legacy(&self) -> Box<[u8; 48]> {
+    pub fn get_block_random_seed_legacy(&self) -> crate::types::Box<[u8; 48]> {
         A::blockchain_api_impl().get_block_random_seed_legacy()
     }
 
@@ -189,8 +197,9 @@ where
         A::blockchain_api_impl().get_prev_block_epoch()
     }
 
+    #[cfg(feature = "alloc")]
     #[inline]
-    pub fn get_prev_block_random_seed_legacy(&self) -> Box<[u8; 48]> {
+    pub fn get_prev_block_random_seed_legacy(&self) -> crate::types::Box<[u8; 48]> {
         A::blockchain_api_impl().get_prev_block_random_seed_legacy()
     }
 
