@@ -1,13 +1,12 @@
-use core::{borrow::Borrow, marker::PhantomData};
+use core::marker::PhantomData;
 
 use crate::{
     api::{
         CryptoApi, CryptoApiImpl, ED25519_KEY_BYTE_LEN, ED25519_SIGNATURE_BYTE_LEN,
         SHA256_RESULT_LEN,
     },
-    types::{BoxedBytes, ManagedBuffer, ManagedByteArray, ManagedType, MessageHashType, H256},
+    types::{ManagedBuffer, ManagedByteArray, MessageHashType},
 };
-use alloc::boxed::Box;
 
 #[derive(Default)]
 pub struct CryptoWrapper<A>
@@ -27,17 +26,20 @@ where
         }
     }
 
-    pub fn sha256<B: Borrow<ManagedBuffer<A>>>(
+    #[cfg(feature = "ei-1-1")]
+    pub fn sha256<B: core::borrow::Borrow<ManagedBuffer<A>>>(
         &self,
         data: B,
     ) -> ManagedByteArray<A, SHA256_RESULT_LEN> {
+        use crate::types::ManagedType;
         ManagedByteArray::from_raw_handle(
             A::crypto_api_impl().sha256(data.borrow().get_raw_handle()),
         )
     }
 
-    pub fn sha256_legacy_alloc(&self, data: &[u8]) -> H256 {
-        H256::from(A::crypto_api_impl().sha256_legacy(data))
+    #[cfg(feature = "alloc")]
+    pub fn sha256_legacy_alloc(&self, data: &[u8]) -> crate::types::H256 {
+        crate::types::H256::from(A::crypto_api_impl().sha256_legacy(data))
     }
 
     pub fn sha256_legacy_managed<const MAX_INPUT_LEN: usize>(
@@ -49,14 +51,20 @@ where
         ManagedByteArray::new_from_bytes(&A::crypto_api_impl().sha256_legacy(data_buffer_slice))
     }
 
-    pub fn keccak256<B: Borrow<ManagedBuffer<A>>>(&self, data: B) -> ManagedByteArray<A, 32> {
+    #[cfg(feature = "ei-1-1")]
+    pub fn keccak256<B: core::borrow::Borrow<ManagedBuffer<A>>>(
+        &self,
+        data: B,
+    ) -> ManagedByteArray<A, 32> {
+        use crate::types::ManagedType;
         ManagedByteArray::from_raw_handle(
             A::crypto_api_impl().keccak256(data.borrow().get_raw_handle()),
         )
     }
 
-    pub fn keccak256_legacy_alloc(&self, data: &[u8]) -> H256 {
-        H256::from(A::crypto_api_impl().keccak256_legacy(data))
+    #[cfg(feature = "alloc")]
+    pub fn keccak256_legacy_alloc(&self, data: &[u8]) -> crate::types::H256 {
+        crate::types::H256::from(A::crypto_api_impl().keccak256_legacy(data))
     }
 
     pub fn keccak256_legacy_managed<const MAX_INPUT_LEN: usize>(
@@ -68,8 +76,9 @@ where
         ManagedByteArray::new_from_bytes(&A::crypto_api_impl().keccak256_legacy(data_buffer_slice))
     }
 
-    pub fn ripemd160(&self, data: &[u8]) -> Box<[u8; 20]> {
-        Box::new(A::crypto_api_impl().ripemd160(data))
+    #[cfg(feature = "alloc")]
+    pub fn ripemd160(&self, data: &[u8]) -> crate::types::Box<[u8; 20]> {
+        crate::types::Box::new(A::crypto_api_impl().ripemd160(data))
     }
 
     pub fn verify_bls(&self, key: &[u8], message: &[u8], signature: &[u8]) -> bool {
@@ -110,7 +119,8 @@ where
         A::crypto_api_impl().verify_custom_secp256k1(key, message, signature, hash_type)
     }
 
-    pub fn encode_secp256k1_der_signature(&self, r: &[u8], s: &[u8]) -> BoxedBytes {
+    #[cfg(feature = "alloc")]
+    pub fn encode_secp256k1_der_signature(&self, r: &[u8], s: &[u8]) -> crate::types::BoxedBytes {
         A::crypto_api_impl().encode_secp256k1_der_signature(r, s)
     }
 }
