@@ -1,6 +1,7 @@
 use super::SEPARATOR;
-use crate::{err_msg, hex_util::hex_digits_to_byte, types::StaticSCError};
-use alloc::vec::Vec;
+use crate::{err_msg, hex_util::hex_digits_to_byte};
+use alloc::{boxed::Box, vec::Vec};
+use elrond_codec::{DecodeError, DecodeErrorHandler, TopDecodeMultiInput};
 
 /// Deserializes from Elrond's smart contract call format.
 ///
@@ -11,7 +12,9 @@ use alloc::vec::Vec;
 ///
 /// HexCallDataDeserializer borrows its input and will allocate new Vecs for each output.
 ///
-/// Converting from bytes to specific argument types is not in scope. Use the `serializer` module for that.
+/// Converting from bytes to specific argument types is not in scope. The `TopDecodeMulti` trait deals with that.
+///
+/// Currently not used anywhere in the framework, but the functionality is available for anyone who needs it.
 ///
 pub struct HexCallDataDeserializer<'a> {
     source: &'a [u8],
@@ -72,19 +75,19 @@ impl<'a> HexCallDataDeserializer<'a> {
     }
 
     /// Gets the next argument, deserializes from hex and returns the resulting bytes.
-    pub fn next_argument(&mut self) -> Result<Option<Vec<u8>>, StaticSCError> {
+    pub fn next_argument(&mut self) -> Result<Option<Vec<u8>>, &'static str> {
         match self.next_argument_hex() {
             None => Ok(None),
             Some(arg_hex) => {
                 if arg_hex.len() % 2 != 0 {
-                    return Err(StaticSCError::from(err_msg::DESERIALIZATION_ODD_DIGITS));
+                    return Err(err_msg::DESERIALIZATION_ODD_DIGITS);
                 }
                 let res_len = arg_hex.len() / 2;
                 let mut res_vec = Vec::with_capacity(res_len);
                 for i in 0..res_len {
                     match hex_digits_to_byte(arg_hex[2 * i], arg_hex[2 * i + 1]) {
                         None => {
-                            return Err(StaticSCError::from(err_msg::DESERIALIZATION_INVALID_BYTE));
+                            return Err(err_msg::DESERIALIZATION_INVALID_BYTE);
                         },
                         Some(byte) => {
                             res_vec.push(byte);
@@ -97,6 +100,25 @@ impl<'a> HexCallDataDeserializer<'a> {
     }
 }
 
+impl<'a> TopDecodeMultiInput for HexCallDataDeserializer<'a> {
+    type ValueInput = Box<[u8]>;
+
+    fn has_next(&self) -> bool {
+        self.has_next()
+    }
+
+    fn next_value_input<H>(&mut self, h: H) -> Result<Self::ValueInput, H::HandledErr>
+    where
+        H: DecodeErrorHandler,
+    {
+        match self.next_argument() {
+            Ok(Some(arg_bytes)) => Ok(arg_bytes.into_boxed_slice()),
+            Ok(None) => Err(h.handle_error(DecodeError::MULTI_TOO_FEW_ARGS)),
+            Err(sc_err) => Err(h.handle_error(DecodeError::from(sc_err))),
+        }
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -208,10 +230,7 @@ mod tests {
         let input: &[u8] = b"func@123";
         let mut de = HexCallDataDeserializer::new(input);
         assert_eq!(de.get_func_name(), &b"func"[..]);
-        assert_eq!(
-            de.next_argument(),
-            Err(StaticSCError::from(err_msg::DESERIALIZATION_ODD_DIGITS))
-        );
+        assert_eq!(de.next_argument(), Err(err_msg::DESERIALIZATION_ODD_DIGITS));
         assert_eq!(de.next_argument(), Ok(None));
         assert_eq!(de.next_argument(), Ok(None));
     }
