@@ -2,8 +2,9 @@ use core::marker::PhantomData;
 
 use crate::{
     api::{EndpointArgumentApi, EndpointArgumentApiImpl, ManagedTypeApi},
-    types::{BigInt, BigUint, ManagedBuffer, ManagedBufferNestedDecodeInput, ManagedType},
-    Box,
+    types::{
+        heap::Box, BigInt, BigUint, ManagedBuffer, ManagedBufferNestedDecodeInput, ManagedType,
+    },
 };
 use elrond_codec::{
     try_execute_then_cast, DecodeError, DecodeErrorHandler, TopDecodeInput, TryStaticCast,
@@ -76,13 +77,31 @@ where
     }
 
     #[inline]
-    fn into_u64(self) -> u64 {
-        AA::argument_api_impl().get_argument_u64(self.arg_index)
+    fn into_max_size_buffer<H, const MAX_LEN: usize>(
+        self,
+        buffer: &mut [u8; MAX_LEN],
+        h: H,
+    ) -> Result<&[u8], H::HandledErr>
+    where
+        H: DecodeErrorHandler,
+    {
+        self.to_managed_buffer().into_max_size_buffer(buffer, h)
     }
 
     #[inline]
-    fn into_i64(self) -> i64 {
-        AA::argument_api_impl().get_argument_i64(self.arg_index)
+    fn into_u64<H>(self, _h: H) -> Result<u64, H::HandledErr>
+    where
+        H: DecodeErrorHandler,
+    {
+        Ok(AA::argument_api_impl().get_argument_u64(self.arg_index))
+    }
+
+    #[inline]
+    fn into_i64<H>(self, _h: H) -> Result<i64, H::HandledErr>
+    where
+        H: DecodeErrorHandler,
+    {
+        Ok(AA::argument_api_impl().get_argument_i64(self.arg_index))
     }
 
     #[inline]
