@@ -1,14 +1,11 @@
-use crate::{
-    api::{ErrorApi, ManagedTypeApi, StorageReadApi, StorageWriteApi},
-    storage::StorageKey,
-};
+use crate::{api::StorageMapperApi, storage::StorageKey};
 
 pub trait StorageMapper<SA>: 'static
 where
-    SA: StorageReadApi + StorageWriteApi + ManagedTypeApi + ErrorApi + Clone + 'static,
+    SA: StorageMapperApi,
 {
     /// Will be called automatically by the `#[storage_mapper]` annotation generated code.
-    fn new(api: SA, base_key: StorageKey<SA>) -> Self;
+    fn new(base_key: StorageKey<SA>) -> Self;
 }
 
 pub trait StorageClearable {
