@@ -1,23 +1,31 @@
+mod fungible_token_mapper;
 mod linked_list_mapper;
 mod map_mapper;
 mod map_storage_mapper;
 mod mapper;
+mod non_fungible_token_mapper;
 mod queue_mapper;
 mod set_mapper;
 mod single_value_mapper;
 mod token_attributes_mapper;
+mod token_mapper;
 mod unordered_set_mapper;
 mod user_mapper;
 mod vec_mapper;
+mod whitelist_mapper;
 
+pub use fungible_token_mapper::FungibleTokenMapper;
 pub use linked_list_mapper::{LinkedListMapper, LinkedListNode};
 pub use map_mapper::MapMapper;
 pub use map_storage_mapper::MapStorageMapper;
 pub use mapper::{StorageClearable, StorageMapper};
+pub use non_fungible_token_mapper::NonFungibleTokenMapper;
 pub use queue_mapper::QueueMapper;
 pub use set_mapper::SetMapper;
 pub use single_value_mapper::SingleValueMapper;
 pub use token_attributes_mapper::TokenAttributesMapper;
+pub use token_mapper::StorageTokenWrapper;
 pub use unordered_set_mapper::UnorderedSetMapper;
 pub use user_mapper::UserMapper;
 pub use vec_mapper::VecMapper;
+pub use whitelist_mapper::WhitelistMapper;
