@@ -1,8 +1,7 @@
-use alloc::string::String;
-use elrond_codec::{EncodeErrorHandler, TopEncodeMulti, TopEncodeMultiOutput, Vec};
+use elrond_codec::{EncodeErrorHandler, TopEncodeMulti, TopEncodeMultiOutput};
 
 use crate::{
-    abi::{OutputAbi, TypeAbi, TypeDescriptionContainer},
+    abi::{OutputAbis, TypeAbi, TypeDescriptionContainer, TypeName},
     api::EndpointFinishApi,
 };
 use core::{
@@ -129,7 +128,7 @@ where
 }
 
 impl<T: TypeAbi, E> TypeAbi for SCResult<T, E> {
-    fn type_name() -> String {
+    fn type_name() -> TypeName {
         T::type_name()
     }
 
@@ -137,7 +136,7 @@ impl<T: TypeAbi, E> TypeAbi for SCResult<T, E> {
     /// just like `()`.
     /// It is also possible to have `SCResult<MultiResultX<...>>`,
     /// so this gives the MultiResult to dissolve into its multiple output ABIs.
-    fn output_abis(output_names: &[&'static str]) -> Vec<OutputAbi> {
+    fn output_abis(output_names: &[&'static str]) -> OutputAbis {
         T::output_abis(output_names)
     }
 
