@@ -1,6 +1,4 @@
-use elrond_codec::{
-    top_encode_number_to_output, EncodeError, EncodeErrorHandler, TopEncodeOutput, TryStaticCast,
-};
+use elrond_codec::{EncodeError, EncodeErrorHandler, TopEncodeOutput, TryStaticCast};
 
 use crate::{
     api::ManagedTypeApi,
@@ -14,20 +12,6 @@ impl<M: ManagedTypeApi> TopEncodeOutput for &mut ManagedBuffer<M> {
         self.overwrite(bytes);
     }
 
-    fn set_u64(self, value: u64) {
-        // it could alternatively be performed via big int conversion
-        // the most important thing is that no heap allocation happens
-        self.overwrite(&[]);
-        top_encode_number_to_output(self, value, false);
-    }
-
-    fn set_i64(self, value: i64) {
-        // it could alternatively be performed via big int conversion
-        // the most important thing is that no heap allocation happens
-        self.overwrite(&[]);
-        top_encode_number_to_output(self, value as u64, true);
-    }
-
     #[inline]
     fn supports_specialized_type<T: TryStaticCast>() -> bool {
         T::type_eq::<ManagedBuffer<M>>() || T::type_eq::<BigUint<M>>() || T::type_eq::<BigInt<M>>()
