@@ -6,7 +6,7 @@ mod multi_value_managed_vec;
 mod multi_value_managed_vec_counted;
 
 pub use async_call_result_managed::{ManagedAsyncCallError, ManagedAsyncCallResult};
-pub use esdt_token_payment_multi_arg::EsdtTokenPaymentMultiArg;
+pub use esdt_token_payment_multi_arg::{EsdtTokenPaymentMultiArg, EsdtTokenPaymentMultiValue};
 pub use multi_value_encoded::{ManagedMultiResultVec, ManagedVarArgs, MultiValueEncoded};
 pub use multi_value_encoded_iter::MultiValueEncodedIterator;
 pub use multi_value_managed_vec::{
