@@ -1,16 +1,18 @@
 mod crypto;
 mod flags;
-mod heap;
+pub mod heap;
 mod interaction;
 mod io;
 mod managed;
 mod static_buffer;
 
-pub use super::{Box, Vec};
 pub use crypto::*;
 pub use flags::*;
-pub use heap::*;
 pub use interaction::*;
 pub use io::*;
 pub use managed::*;
 pub use static_buffer::*;
+
+/// Only import the heap types in contracts when the "alloc" feature is on.
+#[cfg(feature = "alloc")]
+pub use heap::*;
